import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface OrganizationSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Name for Organization.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#name OrganizationSettings#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * settings block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#settings OrganizationSettings#settings}
     *
     * @stability stable
     */
    readonly settings?: OrganizationSettingsSettings[];
}
/**
 * @stability stable
 */
export interface OrganizationSettingsSettingsSaml {
    /**
     * Whether or not SAML is enabled for this organization.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#enabled OrganizationSettings#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface OrganizationSettingsSettingsSamlAutocreateUsersDomains {
    /**
     * List of domains where the SAML automated user creation is enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#domains OrganizationSettings#domains}
     *
     * @stability stable
     */
    readonly domains?: string[];
    /**
     * Whether or not the automated user creation based on SAML domain is enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#enabled OrganizationSettings#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface OrganizationSettingsSettingsSamlIdpInitiatedLogin {
    /**
     * Whether or not a SAML identity provider metadata file was provided to the Datadog organization.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#enabled OrganizationSettings#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface OrganizationSettingsSettingsSamlStrictMode {
    /**
     * Whether or not the SAML strict mode is enabled. If true, all users must log in with SAML.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#enabled OrganizationSettings#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface OrganizationSettingsSettings {
    /**
     * Whether or not the organization users can share widgets outside of Datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#private_widget_share OrganizationSettings#private_widget_share}
     *
     * @stability stable
     */
    readonly privateWidgetShare?: boolean | cdktf.IResolvable;
    /**
     * The access role of the user.
     *
     * Options are `st` (standard user), `adm` (admin user), or `ro` (read-only user). Allowed enum values: `st`, `adm` , `ro`, `ERROR`
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#saml_autocreate_access_role OrganizationSettings#saml_autocreate_access_role}
     *
     * @stability stable
     */
    readonly samlAutocreateAccessRole?: string;
    /**
     * saml block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#saml OrganizationSettings#saml}
     *
     * @stability stable
     */
    readonly saml: OrganizationSettingsSettingsSaml[];
    /**
     * saml_autocreate_users_domains block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#saml_autocreate_users_domains OrganizationSettings#saml_autocreate_users_domains}
     *
     * @stability stable
     */
    readonly samlAutocreateUsersDomains: OrganizationSettingsSettingsSamlAutocreateUsersDomains[];
    /**
     * saml_idp_initiated_login block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#saml_idp_initiated_login OrganizationSettings#saml_idp_initiated_login}
     *
     * @stability stable
     */
    readonly samlIdpInitiatedLogin: OrganizationSettingsSettingsSamlIdpInitiatedLogin[];
    /**
     * saml_strict_mode block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html#saml_strict_mode OrganizationSettings#saml_strict_mode}
     *
     * @stability stable
     */
    readonly samlStrictMode: OrganizationSettingsSettingsSamlStrictMode[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html datadog_organization_settings}.
 *
 * @stability stable
 */
export declare class OrganizationSettings extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/organization_settings.html datadog_organization_settings} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: OrganizationSettingsConfig);
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get publicId(): string;
    private _settings?;
    /**
     * @stability stable
     */
    get settings(): OrganizationSettingsSettings[];
    /**
     * @stability stable
     */
    set settings(value: OrganizationSettingsSettings[]);
    /**
     * @stability stable
     */
    resetSettings(): void;
    /**
     * @stability stable
     */
    get settingsInput(): OrganizationSettingsSettings[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
