import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DashboardConfig extends cdktf.TerraformMetaArguments {
    /**
     * A list of dashboard lists this dashboard belongs to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#dashboard_lists Dashboard#dashboard_lists}
     *
     * @stability stable
     */
    readonly dashboardLists?: number[];
    /**
     * The description of the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#description Dashboard#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Whether this dashboard is read-only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_read_only Dashboard#is_read_only}
     *
     * @stability stable
     */
    readonly isReadOnly?: boolean | cdktf.IResolvable;
    /**
     * The layout type of the dashboard. Valid values are `ordered`, `free`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#layout_type Dashboard#layout_type}
     *
     * @stability stable
     */
    readonly layoutType: string;
    /**
     * The list of handles for the users to notify when changes are made to this dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#notify_list Dashboard#notify_list}
     *
     * @stability stable
     */
    readonly notifyList?: string[];
    /**
     * The reflow type of a new dashboard layout.
     *
     * Set this only when layout type is `ordered`. If set to `fixed`, the dashboard expects all widgets to have a layout, and if it's set to `auto`, widgets should not have layouts. Valid values are `auto`, `fixed`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#reflow_type Dashboard#reflow_type}
     *
     * @stability stable
     */
    readonly reflowType?: string;
    /**
     * Role UUIDs corresponding to users authorized to edit the dashboard. **This feature is currently in beta.**.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#restricted_roles Dashboard#restricted_roles}
     *
     * @stability stable
     */
    readonly restrictedRoles?: string[];
    /**
     * The title of the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * The URL of the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url Dashboard#url}
     *
     * @stability stable
     */
    readonly url?: string;
    /**
     * template_variable block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#template_variable Dashboard#template_variable}
     *
     * @stability stable
     */
    readonly templateVariable?: DashboardTemplateVariable[];
    /**
     * template_variable_preset block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#template_variable_preset Dashboard#template_variable_preset}
     *
     * @stability stable
     */
    readonly templateVariablePreset?: DashboardTemplateVariablePreset[];
    /**
     * widget block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#widget Dashboard#widget}
     *
     * @stability stable
     */
    readonly widget: DashboardWidget[];
}
/**
 * @stability stable
 */
export interface DashboardTemplateVariable {
    /**
     * The list of values that the template variable drop-down is be limited to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#available_values Dashboard#available_values}
     *
     * @stability stable
     */
    readonly availableValues?: string[];
    /**
     * The default value for the template variable on dashboard load.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#default Dashboard#default}
     *
     * @stability stable
     */
    readonly default?: string;
    /**
     * The name of the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The tag prefix associated with the variable. Only tags with this prefix appear in the variable dropdown.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#prefix Dashboard#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
}
/**
 * @stability stable
 */
export interface DashboardTemplateVariablePresetTemplateVariable {
    /**
     * The name of the template variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The value that should be assumed by the template variable in this preset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface DashboardTemplateVariablePreset {
    /**
     * The name of the preset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * template_variable block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#template_variable Dashboard#template_variable}
     *
     * @stability stable
     */
    readonly templateVariable?: DashboardTemplateVariablePresetTemplateVariable[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetAlertGraphDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * Type of visualization to use when displaying the widget. Valid values are `timeseries`, `toplist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#viz_type Dashboard#viz_type}
     *
     * @stability stable
     */
    readonly vizType: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetAlertValueDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The precision to use when displaying the value. Use `*` for maximum precision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#precision Dashboard#precision}
     *
     * @stability stable
     */
    readonly precision?: number;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * The unit for the value displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#unit Dashboard#unit}
     *
     * @stability stable
     */
    readonly unit?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequest {
    /**
     * Whether to show absolute or relative change. Valid values are `absolute`, `relative`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#change_type Dashboard#change_type}
     *
     * @stability stable
     */
    readonly changeType?: string;
    /**
     * Choose from when to compare current data to. Valid values are `hour_before`, `day_before`, `week_before`, `month_before`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compare_to Dashboard#compare_to}
     *
     * @stability stable
     */
    readonly compareTo?: string;
    /**
     * A Boolean indicating whether an increase in the value is good (displayed in green) or not (displayed in red).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#increase_good Dashboard#increase_good}
     *
     * @stability stable
     */
    readonly increaseGood?: boolean | cdktf.IResolvable;
    /**
     * What to order by. Valid values are `change`, `name`, `present`, `past`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_by Dashboard#order_by}
     *
     * @stability stable
     */
    readonly orderBy?: string;
    /**
     * Widget sorting method. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_dir Dashboard#order_dir}
     *
     * @stability stable
     */
    readonly orderDir?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * If set to `true`, displays the current value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_present Dashboard#show_present}
     *
     * @stability stable
     */
    readonly showPresent?: boolean | cdktf.IResolvable;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetChangeDefinitionRequestApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetChangeDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetChangeDefinitionRequestProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetChangeDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetChangeDefinitionRequestSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetChangeDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetChangeDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetCheckStatusDefinition {
    /**
     * The check to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#check Dashboard#check}
     *
     * @stability stable
     */
    readonly check: string;
    /**
     * The check group to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group Dashboard#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * When `grouping = "cluster"`, indicates a list of tags to use for grouping.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The kind of grouping to use. Valid values are `check`, `cluster`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#grouping Dashboard#grouping}
     *
     * @stability stable
     */
    readonly grouping: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * A list of tags to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags Dashboard#tags}
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetDistributionDefinitionRequestApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetDistributionDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetDistributionDefinitionRequestProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetDistributionDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetDistributionDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetDistributionDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinition {
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetDistributionDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetEventStreamDefinition {
    /**
     * The size to use to display an event. Valid values are `s`, `l`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_size Dashboard#event_size}
     *
     * @stability stable
     */
    readonly eventSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetEventTimelineDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetFreeTextDefinition {
    /**
     * The color of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color Dashboard#color}
     *
     * @stability stable
     */
    readonly color?: string;
    /**
     * The size of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#font_size Dashboard#font_size}
     *
     * @stability stable
     */
    readonly fontSize?: string;
    /**
     * The text to display in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text Dashboard#text}
     *
     * @stability stable
     */
    readonly text: string;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGeomapDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGeomapDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGeomapDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGeomapDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGeomapDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGeomapDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGeomapDefinitionRequestLogQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGeomapDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGeomapDefinitionRequestRumQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionStyle {
    /**
     * The color palette to apply to the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * A Boolean indicating whether to flip the palette tones.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette_flip Dashboard#palette_flip}
     *
     * @stability stable
     */
    readonly paletteFlip: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionView {
    /**
     * The two-letter ISO code of a country to focus the map on (or `WORLD`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#focus Dashboard#focus}
     *
     * @stability stable
     */
    readonly focus: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGeomapDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGeomapDefinitionRequest[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGeomapDefinitionStyle[];
    /**
     * view block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view Dashboard#view}
     *
     * @stability stable
     */
    readonly view: DashboardWidgetGeomapDefinitionView[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetAlertGraphDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * Type of visualization to use when displaying the widget. Valid values are `timeseries`, `toplist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#viz_type Dashboard#viz_type}
     *
     * @stability stable
     */
    readonly vizType: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetAlertValueDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The precision to use when displaying the value. Use `*` for maximum precision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#precision Dashboard#precision}
     *
     * @stability stable
     */
    readonly precision?: number;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * The unit for the value displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#unit Dashboard#unit}
     *
     * @stability stable
     */
    readonly unit?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest {
    /**
     * Whether to show absolute or relative change. Valid values are `absolute`, `relative`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#change_type Dashboard#change_type}
     *
     * @stability stable
     */
    readonly changeType?: string;
    /**
     * Choose from when to compare current data to. Valid values are `hour_before`, `day_before`, `week_before`, `month_before`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compare_to Dashboard#compare_to}
     *
     * @stability stable
     */
    readonly compareTo?: string;
    /**
     * A Boolean indicating whether an increase in the value is good (displayed in green) or not (displayed in red).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#increase_good Dashboard#increase_good}
     *
     * @stability stable
     */
    readonly increaseGood?: boolean | cdktf.IResolvable;
    /**
     * What to order by. Valid values are `change`, `name`, `present`, `past`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_by Dashboard#order_by}
     *
     * @stability stable
     */
    readonly orderBy?: string;
    /**
     * Widget sorting method. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_dir Dashboard#order_dir}
     *
     * @stability stable
     */
    readonly orderDir?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * If set to `true`, displays the current value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_present Dashboard#show_present}
     *
     * @stability stable
     */
    readonly showPresent?: boolean | cdktf.IResolvable;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetCheckStatusDefinition {
    /**
     * The check to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#check Dashboard#check}
     *
     * @stability stable
     */
    readonly check: string;
    /**
     * The check group to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group Dashboard#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * When `grouping = "cluster"`, indicates a list of tags to use for grouping.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The kind of grouping to use. Valid values are `check`, `cluster`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#grouping Dashboard#grouping}
     *
     * @stability stable
     */
    readonly grouping: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * A list of tags to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags Dashboard#tags}
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinition {
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetEventStreamDefinition {
    /**
     * The size to use to display an event. Valid values are `s`, `l`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_size Dashboard#event_size}
     *
     * @stability stable
     */
    readonly eventSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetEventTimelineDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetFreeTextDefinition {
    /**
     * The color of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color Dashboard#color}
     *
     * @stability stable
     */
    readonly color?: string;
    /**
     * The size of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#font_size Dashboard#font_size}
     *
     * @stability stable
     */
    readonly fontSize?: string;
    /**
     * The text to display in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text Dashboard#text}
     *
     * @stability stable
     */
    readonly text: string;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle {
    /**
     * The color palette to apply to the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * A Boolean indicating whether to flip the palette tones.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette_flip Dashboard#palette_flip}
     *
     * @stability stable
     */
    readonly paletteFlip: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView {
    /**
     * The two-letter ISO code of a country to focus the map on (or `WORLD`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#focus Dashboard#focus}
     *
     * @stability stable
     */
    readonly focus: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle[];
    /**
     * view block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view Dashboard#view}
     *
     * @stability stable
     */
    readonly view: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent {
    /**
     * The event query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q: string;
    /**
     * The execution method for multi-value filters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinition {
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink[];
    /**
     * event block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event Dashboard#event}
     *
     * @stability stable
     */
    readonly event?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest[];
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest {
    /**
     * fill block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill Dashboard#fill}
     *
     * @stability stable
     */
    readonly fill?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill[];
    /**
     * size block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#size Dashboard#size}
     *
     * @stability stable
     */
    readonly size?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle {
    /**
     * The max value to use to color the map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill_max Dashboard#fill_max}
     *
     * @stability stable
     */
    readonly fillMax?: string;
    /**
     * The min value to use to color the map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill_min Dashboard#fill_min}
     *
     * @stability stable
     */
    readonly fillMin?: string;
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
    /**
     * A Boolean indicating whether to flip the palette tones.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette_flip Dashboard#palette_flip}
     *
     * @stability stable
     */
    readonly paletteFlip?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinition {
    /**
     * The list of tags to group nodes by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group Dashboard#group}
     *
     * @stability stable
     */
    readonly group?: string[];
    /**
     * A Boolean indicating whether to show ungrouped nodes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#no_group_hosts Dashboard#no_group_hosts}
     *
     * @stability stable
     */
    readonly noGroupHosts?: boolean | cdktf.IResolvable;
    /**
     * A Boolean indicating whether to show nodes with no metrics.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#no_metric_hosts Dashboard#no_metric_hosts}
     *
     * @stability stable
     */
    readonly noMetricHosts?: boolean | cdktf.IResolvable;
    /**
     * The type of node used. Valid values are `host`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#node_type Dashboard#node_type}
     *
     * @stability stable
     */
    readonly nodeType?: string;
    /**
     * The list of tags to filter nodes by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scope Dashboard#scope}
     *
     * @stability stable
     */
    readonly scope?: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetIframeDefinition {
    /**
     * The URL to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url Dashboard#url}
     *
     * @stability stable
     */
    readonly url: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetImageDefinition {
    /**
     * Whether to display a background or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_background Dashboard#has_background}
     *
     * @stability stable
     */
    readonly hasBackground?: boolean | cdktf.IResolvable;
    /**
     * Whether to display a border or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_border Dashboard#has_border}
     *
     * @stability stable
     */
    readonly hasBorder?: boolean | cdktf.IResolvable;
    /**
     * The horizontal alignment for the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#horizontal_align Dashboard#horizontal_align}
     *
     * @stability stable
     */
    readonly horizontalAlign?: string;
    /**
     * The margins to use around the image.
     *
     * Note: `small` and `large` values are deprecated. Valid values are `sm`, `md`, `lg`, `small`, `large`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#margin Dashboard#margin}
     *
     * @stability stable
     */
    readonly margin?: string;
    /**
     * The preferred method to adapt the dimensions of the image.
     *
     * The values are based on the image `object-fit` CSS properties. Note: `zoom`, `fit` and `center` values are deprecated. Valid values are `fill`, `contain`, `cover`, `none`, `scale-down`, `zoom`, `fit`, `center`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sizing Dashboard#sizing}
     *
     * @stability stable
     */
    readonly sizing?: string;
    /**
     * The URL to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url Dashboard#url}
     *
     * @stability stable
     */
    readonly url: string;
    /**
     * The URL in dark mode to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url_dark_theme Dashboard#url_dark_theme}
     *
     * @stability stable
     */
    readonly urlDarkTheme?: string;
    /**
     * The vertical alignment for the widget. Valid values are `center`, `top`, `bottom`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#vertical_align Dashboard#vertical_align}
     *
     * @stability stable
     */
    readonly verticalAlign?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort {
    /**
     * The facet path for the column.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#column Dashboard#column}
     *
     * @stability stable
     */
    readonly column: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetLogStreamDefinition {
    /**
     * Stringified list of columns to use, for example: `["column1","column2","column3"]`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#columns Dashboard#columns}
     *
     * @stability stable
     */
    readonly columns?: string[];
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The number of log lines to display. Valid values are `inline`, `expanded-md`, `expanded-lg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#message_display Dashboard#message_display}
     *
     * @stability stable
     */
    readonly messageDisplay?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: string;
    /**
     * If the date column should be displayed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_date_column Dashboard#show_date_column}
     *
     * @stability stable
     */
    readonly showDateColumn?: boolean | cdktf.IResolvable;
    /**
     * If the message column should be displayed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_message_column Dashboard#show_message_column}
     *
     * @stability stable
     */
    readonly showMessageColumn?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetManageStatusDefinition {
    /**
     * Whether to colorize text or background. Valid values are `background`, `text`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color_preference Dashboard#color_preference}
     *
     * @stability stable
     */
    readonly colorPreference?: string;
    /**
     * The display setting to use. Valid values are `counts`, `countsAndList`, `list`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_format Dashboard#display_format}
     *
     * @stability stable
     */
    readonly displayFormat?: string;
    /**
     * A Boolean indicating whether to hide empty categories.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_zero_counts Dashboard#hide_zero_counts}
     *
     * @stability stable
     */
    readonly hideZeroCounts?: boolean | cdktf.IResolvable;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * A Boolean indicating whether to show when monitors/groups last triggered.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_last_triggered Dashboard#show_last_triggered}
     *
     * @stability stable
     */
    readonly showLastTriggered?: boolean | cdktf.IResolvable;
    /**
     * The method to sort the monitors.
     *
     * Valid values are `name`, `group`, `status`, `tags`, `triggered`, `group,asc`, `group,desc`, `name,asc`, `name,desc`, `status,asc`, `status,desc`, `tags,asc`, `tags,desc`, `triggered,asc`, `triggered,desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * The summary type to use. Valid values are `monitors`, `groups`, `combined`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#summary_type Dashboard#summary_type}
     *
     * @stability stable
     */
    readonly summaryType?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetNoteDefinition {
    /**
     * The background color of the note.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#background_color Dashboard#background_color}
     *
     * @stability stable
     */
    readonly backgroundColor?: string;
    /**
     * The content of the note.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#content Dashboard#content}
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * The size of the text.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#font_size Dashboard#font_size}
     *
     * @stability stable
     */
    readonly fontSize?: string;
    /**
     * Whether to add padding or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_padding Dashboard#has_padding}
     *
     * @stability stable
     */
    readonly hasPadding?: boolean | cdktf.IResolvable;
    /**
     * Whether to show a tick or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_tick Dashboard#show_tick}
     *
     * @stability stable
     */
    readonly showTick?: boolean | cdktf.IResolvable;
    /**
     * The alignment of the widget's text. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * When `tick = true`, a string indicating on which side of the widget the tick should be displayed.
     *
     * Valid values are `bottom`, `left`, `right`, `top`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tick_edge Dashboard#tick_edge}
     *
     * @stability stable
     */
    readonly tickEdge?: string;
    /**
     * When `tick = true`, a string with a percent sign indicating the position of the tick, for example: `tick_pos = "50%"` is centered alignment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tick_pos Dashboard#tick_pos}
     *
     * @stability stable
     */
    readonly tickPos?: string;
    /**
     * The vertical alignment for the widget. Valid values are `center`, `top`, `bottom`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#vertical_align Dashboard#vertical_align}
     *
     * @stability stable
     */
    readonly verticalAlign?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns {
    /**
     * A user-assigned alias for the column.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * The column name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQuery {
    /**
     * The environment name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * The operation name associated with the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The organization's host group name and value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag Dashboard#primary_tag}
     *
     * @stability stable
     */
    readonly primaryTag: string;
    /**
     * The resource name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource Dashboard#resource}
     *
     * @stability stable
     */
    readonly resource?: string;
    /**
     * The level of detail for the request. Valid values are `service`, `resource`, `span`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#row_type Dashboard#row_type}
     *
     * @stability stable
     */
    readonly rowType: string;
    /**
     * The service name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * columns block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#columns Dashboard#columns}
     *
     * @stability stable
     */
    readonly columns?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest {
    /**
     * The aggregator to use for time aggregation. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The alias for the column name (defaults to metric name).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell.
     *
     * List items one of `number`, `bar`. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string[];
    /**
     * The number of lines to show in the table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The sort order for the rows. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQuery[];
    /**
     * apm_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_stats_query Dashboard#apm_stats_query}
     *
     * @stability stable
     */
    readonly apmStatsQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQuery[];
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinition {
    /**
     * Controls the display of the search bar. Valid values are `always`, `never`, `auto`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_search_bar Dashboard#has_search_bar}
     *
     * @stability stable
     */
    readonly hasSearchBar?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest {
    /**
     * The aggregator to use for time aggregation. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQuery[];
    /**
     * audit_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#audit_query Dashboard#audit_query}
     *
     * @stability stable
     */
    readonly auditQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQuery[];
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinition {
    /**
     * A Boolean indicating whether to automatically scale the tile.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#autoscale Dashboard#autoscale}
     *
     * @stability stable
     */
    readonly autoscale?: boolean | cdktf.IResolvable;
    /**
     * The unit for the value displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_unit Dashboard#custom_unit}
     *
     * @stability stable
     */
    readonly customUnit?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The precision to use when displaying the tile.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#precision Dashboard#precision}
     *
     * @stability stable
     */
    readonly precision?: number;
    /**
     * The alignment of the widget's text. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX {
    /**
     * Aggregator used for the request. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY {
    /**
     * Aggregator used for the request. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest {
    /**
     * x block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#x Dashboard#x}
     *
     * @stability stable
     */
    readonly x?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX[];
    /**
     * y block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#y Dashboard#y}
     *
     * @stability stable
     */
    readonly y?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinition {
    /**
     * List of groups used for colors.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color_by_groups Dashboard#color_by_groups}
     *
     * @stability stable
     */
    readonly colorByGroups?: string[];
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest[];
    /**
     * xaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#xaxis Dashboard#xaxis}
     *
     * @stability stable
     */
    readonly xaxis?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis[];
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinition {
    /**
     * The global time target of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#global_time_target Dashboard#global_time_target}
     *
     * @stability stable
     */
    readonly globalTimeTarget?: string;
    /**
     * Whether to show the error budget or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_error_budget Dashboard#show_error_budget}
     *
     * @stability stable
     */
    readonly showErrorBudget?: boolean | cdktf.IResolvable;
    /**
     * The ID of the service level objective used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#slo_id Dashboard#slo_id}
     *
     * @stability stable
     */
    readonly sloId: string;
    /**
     * A list of time windows to display in the widget.
     *
     * Valid values are `7d`, `30d`, `90d`, `week_to_date`, `previous_week`, `month_to_date`, `previous_month`, `global_time`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#time_windows Dashboard#time_windows}
     *
     * @stability stable
     */
    readonly timeWindows: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * The view mode for the widget. Valid values are `overall`, `component`, `both`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view_mode Dashboard#view_mode}
     *
     * @stability stable
     */
    readonly viewMode: string;
    /**
     * The type of view to use when displaying the widget. Only `detail` is supported.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view_type Dashboard#view_type}
     *
     * @stability stable
     */
    readonly viewType: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetServicemapDefinition {
    /**
     * Your environment and primary tag (or `*` if enabled for your account).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filters Dashboard#filters}
     *
     * @stability stable
     */
    readonly filters: string[];
    /**
     * The ID of the service to map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionEvent {
    /**
     * The event query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q: string;
    /**
     * The execution method for multi-value filters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionMarker {
    /**
     * How the marker lines are displayed, options are one of {`error`, `warning`, `info`, `ok`} combined with one of {`dashed`, `solid`, `bold`}.
     *
     * Example: `error dashed`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_type Dashboard#display_type}
     *
     * @stability stable
     */
    readonly displayType?: string;
    /**
     * A label for the line or range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * A mathematical expression describing the marker, for example: `y > 1`, `-5 < y < 0`, `y = 19`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestMetadata {
    /**
     * The expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias_name Dashboard#alias_name}
     *
     * @stability stable
     */
    readonly aliasName?: string;
    /**
     * The expression name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#expression Dashboard#expression}
     *
     * @stability stable
     */
    readonly expression: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestStyle {
    /**
     * The type of lines displayed. Valid values are `dashed`, `dotted`, `solid`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#line_type Dashboard#line_type}
     *
     * @stability stable
     */
    readonly lineType?: string;
    /**
     * The width of line displayed. Valid values are `normal`, `thick`, `thin`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#line_width Dashboard#line_width}
     *
     * @stability stable
     */
    readonly lineWidth?: string;
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequest {
    /**
     * How to display the marker lines. Valid values are `area`, `bars`, `line`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_type Dashboard#display_type}
     *
     * @stability stable
     */
    readonly displayType?: string;
    /**
     * A Boolean indicating whether the request uses the right or left Y-Axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#on_right_yaxis Dashboard#on_right_yaxis}
     *
     * @stability stable
     */
    readonly onRightYaxis?: boolean | cdktf.IResolvable;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQuery[];
    /**
     * audit_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#audit_query Dashboard#audit_query}
     *
     * @stability stable
     */
    readonly auditQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQuery[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQuery[];
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metadata Dashboard#metadata}
     *
     * @stability stable
     */
    readonly metadata?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestMetadata[];
    /**
     * network_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#network_query Dashboard#network_query}
     *
     * @stability stable
     */
    readonly networkQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestNetworkQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRightYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinition {
    /**
     * A list of columns to display in the legend. Valid values are `value`, `avg`, `sum`, `min`, `max`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_columns Dashboard#legend_columns}
     *
     * @stability stable
     */
    readonly legendColumns?: string[];
    /**
     * The layout of the legend displayed in the widget. Valid values are `auto`, `horizontal`, `vertical`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_layout Dashboard#legend_layout}
     *
     * @stability stable
     */
    readonly legendLayout?: string;
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionCustomLink[];
    /**
     * event block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event Dashboard#event}
     *
     * @stability stable
     */
    readonly event?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionEvent[];
    /**
     * marker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#marker Dashboard#marker}
     *
     * @stability stable
     */
    readonly marker?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionMarker[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequest[];
    /**
     * right_yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#right_yaxis Dashboard#right_yaxis}
     *
     * @stability stable
     */
    readonly rightYaxis?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRightYaxis[];
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionYaxis[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestApmQuery[];
    /**
     * audit_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#audit_query Dashboard#audit_query}
     *
     * @stability stable
     */
    readonly auditQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestAuditQuery[];
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetToplistDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetToplistDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTraceServiceDefinition {
    /**
     * The number of columns to display. Valid values are `one_column`, `two_column`, `three_column`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_format Dashboard#display_format}
     *
     * @stability stable
     */
    readonly displayFormat?: string;
    /**
     * APM environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * Whether to show the latency breakdown or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_breakdown Dashboard#show_breakdown}
     *
     * @stability stable
     */
    readonly showBreakdown?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the latency distribution or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_distribution Dashboard#show_distribution}
     *
     * @stability stable
     */
    readonly showDistribution?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the error metrics or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_errors Dashboard#show_errors}
     *
     * @stability stable
     */
    readonly showErrors?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the hits metrics or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_hits Dashboard#show_hits}
     *
     * @stability stable
     */
    readonly showHits?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the latency metrics or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_latency Dashboard#show_latency}
     *
     * @stability stable
     */
    readonly showLatency?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the resource list or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_resource_list Dashboard#show_resource_list}
     *
     * @stability stable
     */
    readonly showResourceList?: boolean | cdktf.IResolvable;
    /**
     * The size of the widget. Valid values are `small`, `medium`, `large`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#size_format Dashboard#size_format}
     *
     * @stability stable
     */
    readonly sizeFormat?: string;
    /**
     * APM span name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#span_name Dashboard#span_name}
     *
     * @stability stable
     */
    readonly spanName: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetWidgetLayout {
    /**
     * The height of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#height Dashboard#height}
     *
     * @stability stable
     */
    readonly height: number;
    /**
     * Whether the widget should be the first one on the second column in high density or not.
     *
     * Only for the new dashboard layout and only one widget in the dashboard should have this property set to `true`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_column_break Dashboard#is_column_break}
     *
     * @stability stable
     */
    readonly isColumnBreak?: boolean | cdktf.IResolvable;
    /**
     * The width of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#width Dashboard#width}
     *
     * @stability stable
     */
    readonly width: number;
    /**
     * The position of the widget on the x (horizontal) axis. Should be greater than or equal to 0.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#x Dashboard#x}
     *
     * @stability stable
     */
    readonly x: number;
    /**
     * The position of the widget on the y (vertical) axis. Should be greater than or equal to 0.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#y Dashboard#y}
     *
     * @stability stable
     */
    readonly y: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidget {
    /**
     * alert_graph_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_graph_definition Dashboard#alert_graph_definition}
     *
     * @stability stable
     */
    readonly alertGraphDefinition?: DashboardWidgetGroupDefinitionWidgetAlertGraphDefinition[];
    /**
     * alert_value_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_value_definition Dashboard#alert_value_definition}
     *
     * @stability stable
     */
    readonly alertValueDefinition?: DashboardWidgetGroupDefinitionWidgetAlertValueDefinition[];
    /**
     * change_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#change_definition Dashboard#change_definition}
     *
     * @stability stable
     */
    readonly changeDefinition?: DashboardWidgetGroupDefinitionWidgetChangeDefinition[];
    /**
     * check_status_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#check_status_definition Dashboard#check_status_definition}
     *
     * @stability stable
     */
    readonly checkStatusDefinition?: DashboardWidgetGroupDefinitionWidgetCheckStatusDefinition[];
    /**
     * distribution_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#distribution_definition Dashboard#distribution_definition}
     *
     * @stability stable
     */
    readonly distributionDefinition?: DashboardWidgetGroupDefinitionWidgetDistributionDefinition[];
    /**
     * event_stream_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_stream_definition Dashboard#event_stream_definition}
     *
     * @stability stable
     */
    readonly eventStreamDefinition?: DashboardWidgetGroupDefinitionWidgetEventStreamDefinition[];
    /**
     * event_timeline_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_timeline_definition Dashboard#event_timeline_definition}
     *
     * @stability stable
     */
    readonly eventTimelineDefinition?: DashboardWidgetGroupDefinitionWidgetEventTimelineDefinition[];
    /**
     * free_text_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#free_text_definition Dashboard#free_text_definition}
     *
     * @stability stable
     */
    readonly freeTextDefinition?: DashboardWidgetGroupDefinitionWidgetFreeTextDefinition[];
    /**
     * geomap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#geomap_definition Dashboard#geomap_definition}
     *
     * @stability stable
     */
    readonly geomapDefinition?: DashboardWidgetGroupDefinitionWidgetGeomapDefinition[];
    /**
     * heatmap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#heatmap_definition Dashboard#heatmap_definition}
     *
     * @stability stable
     */
    readonly heatmapDefinition?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinition[];
    /**
     * hostmap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hostmap_definition Dashboard#hostmap_definition}
     *
     * @stability stable
     */
    readonly hostmapDefinition?: DashboardWidgetGroupDefinitionWidgetHostmapDefinition[];
    /**
     * iframe_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#iframe_definition Dashboard#iframe_definition}
     *
     * @stability stable
     */
    readonly iframeDefinition?: DashboardWidgetGroupDefinitionWidgetIframeDefinition[];
    /**
     * image_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_definition Dashboard#image_definition}
     *
     * @stability stable
     */
    readonly imageDefinition?: DashboardWidgetGroupDefinitionWidgetImageDefinition[];
    /**
     * log_stream_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_stream_definition Dashboard#log_stream_definition}
     *
     * @stability stable
     */
    readonly logStreamDefinition?: DashboardWidgetGroupDefinitionWidgetLogStreamDefinition[];
    /**
     * manage_status_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#manage_status_definition Dashboard#manage_status_definition}
     *
     * @stability stable
     */
    readonly manageStatusDefinition?: DashboardWidgetGroupDefinitionWidgetManageStatusDefinition[];
    /**
     * note_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#note_definition Dashboard#note_definition}
     *
     * @stability stable
     */
    readonly noteDefinition?: DashboardWidgetGroupDefinitionWidgetNoteDefinition[];
    /**
     * query_table_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query_table_definition Dashboard#query_table_definition}
     *
     * @stability stable
     */
    readonly queryTableDefinition?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinition[];
    /**
     * query_value_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query_value_definition Dashboard#query_value_definition}
     *
     * @stability stable
     */
    readonly queryValueDefinition?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinition[];
    /**
     * scatterplot_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scatterplot_definition Dashboard#scatterplot_definition}
     *
     * @stability stable
     */
    readonly scatterplotDefinition?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinition[];
    /**
     * service_level_objective_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service_level_objective_definition Dashboard#service_level_objective_definition}
     *
     * @stability stable
     */
    readonly serviceLevelObjectiveDefinition?: DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinition[];
    /**
     * servicemap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#servicemap_definition Dashboard#servicemap_definition}
     *
     * @stability stable
     */
    readonly servicemapDefinition?: DashboardWidgetGroupDefinitionWidgetServicemapDefinition[];
    /**
     * timeseries_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeseries_definition Dashboard#timeseries_definition}
     *
     * @stability stable
     */
    readonly timeseriesDefinition?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinition[];
    /**
     * toplist_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#toplist_definition Dashboard#toplist_definition}
     *
     * @stability stable
     */
    readonly toplistDefinition?: DashboardWidgetGroupDefinitionWidgetToplistDefinition[];
    /**
     * trace_service_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#trace_service_definition Dashboard#trace_service_definition}
     *
     * @stability stable
     */
    readonly traceServiceDefinition?: DashboardWidgetGroupDefinitionWidgetTraceServiceDefinition[];
    /**
     * widget_layout block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#widget_layout Dashboard#widget_layout}
     *
     * @stability stable
     */
    readonly widgetLayout?: DashboardWidgetGroupDefinitionWidgetWidgetLayout[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinition {
    /**
     * The background color of the group title, options: `vivid_blue`, `vivid_purple`, `vivid_pink`, `vivid_orange`, `vivid_yellow`, `vivid_green`, `blue`, `purple`, `pink`, `orange`, `yellow`, `green`, `gray` or `white`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#background_color Dashboard#background_color}
     *
     * @stability stable
     */
    readonly backgroundColor?: string;
    /**
     * The image URL to display as a banner for the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#banner_img Dashboard#banner_img}
     *
     * @stability stable
     */
    readonly bannerImg?: string;
    /**
     * The layout type of the group. Valid values are `ordered`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#layout_type Dashboard#layout_type}
     *
     * @stability stable
     */
    readonly layoutType: string;
    /**
     * Whether to show the title or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_title Dashboard#show_title}
     *
     * @stability stable
     */
    readonly showTitle?: boolean | cdktf.IResolvable;
    /**
     * The title of the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * widget block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#widget Dashboard#widget}
     *
     * @stability stable
     */
    readonly widget: DashboardWidgetGroupDefinitionWidget[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionEvent {
    /**
     * The event query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q: string;
    /**
     * The execution method for multi-value filters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHeatmapDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHeatmapDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHeatmapDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHeatmapDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHeatmapDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHeatmapDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHeatmapDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHeatmapDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHeatmapDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHeatmapDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetHeatmapDefinitionRequestApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetHeatmapDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetHeatmapDefinitionRequestProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetHeatmapDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetHeatmapDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetHeatmapDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHeatmapDefinition {
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetHeatmapDefinitionCustomLink[];
    /**
     * event block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event Dashboard#event}
     *
     * @stability stable
     */
    readonly event?: DashboardWidgetHeatmapDefinitionEvent[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetHeatmapDefinitionRequest[];
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetHeatmapDefinitionYaxis[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestFillApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestFillApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestFillApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestFillLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestFillLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestFillLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestFillRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestFillRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestFillRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFillSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestFill {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetHostmapDefinitionRequestFillApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetHostmapDefinitionRequestFillLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetHostmapDefinitionRequestFillProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetHostmapDefinitionRequestFillRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetHostmapDefinitionRequestFillSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestSizeApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestSizeLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestSizeRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSizeSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequestSize {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetHostmapDefinitionRequestSizeApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetHostmapDefinitionRequestSizeLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetHostmapDefinitionRequestSizeProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetHostmapDefinitionRequestSizeRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetHostmapDefinitionRequestSizeSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionRequest {
    /**
     * fill block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill Dashboard#fill}
     *
     * @stability stable
     */
    readonly fill?: DashboardWidgetHostmapDefinitionRequestFill[];
    /**
     * size block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#size Dashboard#size}
     *
     * @stability stable
     */
    readonly size?: DashboardWidgetHostmapDefinitionRequestSize[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinitionStyle {
    /**
     * The max value to use to color the map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill_max Dashboard#fill_max}
     *
     * @stability stable
     */
    readonly fillMax?: string;
    /**
     * The min value to use to color the map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill_min Dashboard#fill_min}
     *
     * @stability stable
     */
    readonly fillMin?: string;
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
    /**
     * A Boolean indicating whether to flip the palette tones.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette_flip Dashboard#palette_flip}
     *
     * @stability stable
     */
    readonly paletteFlip?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface DashboardWidgetHostmapDefinition {
    /**
     * The list of tags to group nodes by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group Dashboard#group}
     *
     * @stability stable
     */
    readonly group?: string[];
    /**
     * A Boolean indicating whether to show ungrouped nodes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#no_group_hosts Dashboard#no_group_hosts}
     *
     * @stability stable
     */
    readonly noGroupHosts?: boolean | cdktf.IResolvable;
    /**
     * A Boolean indicating whether to show nodes with no metrics.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#no_metric_hosts Dashboard#no_metric_hosts}
     *
     * @stability stable
     */
    readonly noMetricHosts?: boolean | cdktf.IResolvable;
    /**
     * The type of node used. Valid values are `host`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#node_type Dashboard#node_type}
     *
     * @stability stable
     */
    readonly nodeType?: string;
    /**
     * The list of tags to filter nodes by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scope Dashboard#scope}
     *
     * @stability stable
     */
    readonly scope?: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetHostmapDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetHostmapDefinitionRequest[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetHostmapDefinitionStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetIframeDefinition {
    /**
     * The URL to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url Dashboard#url}
     *
     * @stability stable
     */
    readonly url: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetImageDefinition {
    /**
     * Whether to display a background or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_background Dashboard#has_background}
     *
     * @stability stable
     */
    readonly hasBackground?: boolean | cdktf.IResolvable;
    /**
     * Whether to display a border or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_border Dashboard#has_border}
     *
     * @stability stable
     */
    readonly hasBorder?: boolean | cdktf.IResolvable;
    /**
     * The horizontal alignment for the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#horizontal_align Dashboard#horizontal_align}
     *
     * @stability stable
     */
    readonly horizontalAlign?: string;
    /**
     * The margins to use around the image.
     *
     * Note: `small` and `large` values are deprecated. Valid values are `sm`, `md`, `lg`, `small`, `large`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#margin Dashboard#margin}
     *
     * @stability stable
     */
    readonly margin?: string;
    /**
     * The preferred method to adapt the dimensions of the image.
     *
     * The values are based on the image `object-fit` CSS properties. Note: `zoom`, `fit` and `center` values are deprecated. Valid values are `fill`, `contain`, `cover`, `none`, `scale-down`, `zoom`, `fit`, `center`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sizing Dashboard#sizing}
     *
     * @stability stable
     */
    readonly sizing?: string;
    /**
     * The URL to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url Dashboard#url}
     *
     * @stability stable
     */
    readonly url: string;
    /**
     * The URL in dark mode to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url_dark_theme Dashboard#url_dark_theme}
     *
     * @stability stable
     */
    readonly urlDarkTheme?: string;
    /**
     * The vertical alignment for the widget. Valid values are `center`, `top`, `bottom`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#vertical_align Dashboard#vertical_align}
     *
     * @stability stable
     */
    readonly verticalAlign?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetLogStreamDefinitionSort {
    /**
     * The facet path for the column.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#column Dashboard#column}
     *
     * @stability stable
     */
    readonly column: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetLogStreamDefinition {
    /**
     * Stringified list of columns to use, for example: `["column1","column2","column3"]`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#columns Dashboard#columns}
     *
     * @stability stable
     */
    readonly columns?: string[];
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The number of log lines to display. Valid values are `inline`, `expanded-md`, `expanded-lg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#message_display Dashboard#message_display}
     *
     * @stability stable
     */
    readonly messageDisplay?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: string;
    /**
     * If the date column should be displayed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_date_column Dashboard#show_date_column}
     *
     * @stability stable
     */
    readonly showDateColumn?: boolean | cdktf.IResolvable;
    /**
     * If the message column should be displayed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_message_column Dashboard#show_message_column}
     *
     * @stability stable
     */
    readonly showMessageColumn?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetLogStreamDefinitionSort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetManageStatusDefinition {
    /**
     * Whether to colorize text or background. Valid values are `background`, `text`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color_preference Dashboard#color_preference}
     *
     * @stability stable
     */
    readonly colorPreference?: string;
    /**
     * The display setting to use. Valid values are `counts`, `countsAndList`, `list`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_format Dashboard#display_format}
     *
     * @stability stable
     */
    readonly displayFormat?: string;
    /**
     * A Boolean indicating whether to hide empty categories.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_zero_counts Dashboard#hide_zero_counts}
     *
     * @stability stable
     */
    readonly hideZeroCounts?: boolean | cdktf.IResolvable;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * A Boolean indicating whether to show when monitors/groups last triggered.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_last_triggered Dashboard#show_last_triggered}
     *
     * @stability stable
     */
    readonly showLastTriggered?: boolean | cdktf.IResolvable;
    /**
     * The method to sort the monitors.
     *
     * Valid values are `name`, `group`, `status`, `tags`, `triggered`, `group,asc`, `group,desc`, `name,asc`, `name,desc`, `status,asc`, `status,desc`, `tags,asc`, `tags,desc`, `triggered,asc`, `triggered,desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * The summary type to use. Valid values are `monitors`, `groups`, `combined`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#summary_type Dashboard#summary_type}
     *
     * @stability stable
     */
    readonly summaryType?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetNoteDefinition {
    /**
     * The background color of the note.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#background_color Dashboard#background_color}
     *
     * @stability stable
     */
    readonly backgroundColor?: string;
    /**
     * The content of the note.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#content Dashboard#content}
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * The size of the text.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#font_size Dashboard#font_size}
     *
     * @stability stable
     */
    readonly fontSize?: string;
    /**
     * Whether to add padding or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_padding Dashboard#has_padding}
     *
     * @stability stable
     */
    readonly hasPadding?: boolean | cdktf.IResolvable;
    /**
     * Whether to show a tick or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_tick Dashboard#show_tick}
     *
     * @stability stable
     */
    readonly showTick?: boolean | cdktf.IResolvable;
    /**
     * The alignment of the widget's text. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * When `tick = true`, a string indicating on which side of the widget the tick should be displayed.
     *
     * Valid values are `bottom`, `left`, `right`, `top`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tick_edge Dashboard#tick_edge}
     *
     * @stability stable
     */
    readonly tickEdge?: string;
    /**
     * When `tick = true`, a string with a percent sign indicating the position of the tick, for example: `tick_pos = "50%"` is centered alignment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tick_pos Dashboard#tick_pos}
     *
     * @stability stable
     */
    readonly tickPos?: string;
    /**
     * The vertical alignment for the widget. Valid values are `center`, `top`, `bottom`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#vertical_align Dashboard#vertical_align}
     *
     * @stability stable
     */
    readonly verticalAlign?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryTableDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryTableDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryTableDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestApmStatsQueryColumns {
    /**
     * A user-assigned alias for the column.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * The column name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestApmStatsQuery {
    /**
     * The environment name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * The operation name associated with the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The organization's host group name and value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag Dashboard#primary_tag}
     *
     * @stability stable
     */
    readonly primaryTag: string;
    /**
     * The resource name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource Dashboard#resource}
     *
     * @stability stable
     */
    readonly resource?: string;
    /**
     * The level of detail for the request. Valid values are `service`, `resource`, `span`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#row_type Dashboard#row_type}
     *
     * @stability stable
     */
    readonly rowType: string;
    /**
     * The service name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * columns block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#columns Dashboard#columns}
     *
     * @stability stable
     */
    readonly columns?: DashboardWidgetQueryTableDefinitionRequestApmStatsQueryColumns[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetQueryTableDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetQueryTableDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryTableDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryTableDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryTableDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetQueryTableDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetQueryTableDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetQueryTableDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetQueryTableDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetQueryTableDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryTableDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryTableDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryTableDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryTableDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinitionRequest {
    /**
     * The aggregator to use for time aggregation. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The alias for the column name (defaults to metric name).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell.
     *
     * List items one of `number`, `bar`. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string[];
    /**
     * The number of lines to show in the table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The sort order for the rows. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetQueryTableDefinitionRequestApmQuery[];
    /**
     * apm_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_stats_query Dashboard#apm_stats_query}
     *
     * @stability stable
     */
    readonly apmStatsQuery?: DashboardWidgetQueryTableDefinitionRequestApmStatsQuery[];
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetQueryTableDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetQueryTableDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetQueryTableDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetQueryTableDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetQueryTableDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetQueryTableDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetQueryTableDefinitionRequestSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryTableDefinition {
    /**
     * Controls the display of the search bar. Valid values are `always`, `never`, `auto`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_search_bar Dashboard#has_search_bar}
     *
     * @stability stable
     */
    readonly hasSearchBar?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetQueryTableDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetQueryTableDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryValueDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryValueDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryValueDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryValueDefinitionRequestAuditQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryValueDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryValueDefinitionRequestAuditQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetQueryValueDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetQueryValueDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryValueDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryValueDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryValueDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetQueryValueDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetQueryValueDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetQueryValueDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetQueryValueDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetQueryValueDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryValueDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryValueDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryValueDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetQueryValueDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinitionRequest {
    /**
     * The aggregator to use for time aggregation. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetQueryValueDefinitionRequestApmQuery[];
    /**
     * audit_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#audit_query Dashboard#audit_query}
     *
     * @stability stable
     */
    readonly auditQuery?: DashboardWidgetQueryValueDefinitionRequestAuditQuery[];
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetQueryValueDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetQueryValueDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetQueryValueDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetQueryValueDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetQueryValueDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetQueryValueDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetQueryValueDefinitionRequestSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetQueryValueDefinition {
    /**
     * A Boolean indicating whether to automatically scale the tile.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#autoscale Dashboard#autoscale}
     *
     * @stability stable
     */
    readonly autoscale?: boolean | cdktf.IResolvable;
    /**
     * The unit for the value displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_unit Dashboard#custom_unit}
     *
     * @stability stable
     */
    readonly customUnit?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The precision to use when displaying the tile.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#precision Dashboard#precision}
     *
     * @stability stable
     */
    readonly precision?: number;
    /**
     * The alignment of the widget's text. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetQueryValueDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetQueryValueDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestXApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestXApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestXApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestXLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestXLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestXLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestXRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestXRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestXRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestXSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestX {
    /**
     * Aggregator used for the request. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetScatterplotDefinitionRequestXApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetScatterplotDefinitionRequestXLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetScatterplotDefinitionRequestXProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetScatterplotDefinitionRequestXRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetScatterplotDefinitionRequestXSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestYApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestYApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestYApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestYLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestYLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestYLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestYRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestYRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestYRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestYSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequestY {
    /**
     * Aggregator used for the request. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetScatterplotDefinitionRequestYApmQuery[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetScatterplotDefinitionRequestYLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetScatterplotDefinitionRequestYProcessQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetScatterplotDefinitionRequestYRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetScatterplotDefinitionRequestYSecurityQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionRequest {
    /**
     * x block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#x Dashboard#x}
     *
     * @stability stable
     */
    readonly x?: DashboardWidgetScatterplotDefinitionRequestX[];
    /**
     * y block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#y Dashboard#y}
     *
     * @stability stable
     */
    readonly y?: DashboardWidgetScatterplotDefinitionRequestY[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionXaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetScatterplotDefinition {
    /**
     * List of groups used for colors.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color_by_groups Dashboard#color_by_groups}
     *
     * @stability stable
     */
    readonly colorByGroups?: string[];
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetScatterplotDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetScatterplotDefinitionRequest[];
    /**
     * xaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#xaxis Dashboard#xaxis}
     *
     * @stability stable
     */
    readonly xaxis?: DashboardWidgetScatterplotDefinitionXaxis[];
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetScatterplotDefinitionYaxis[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetServiceLevelObjectiveDefinition {
    /**
     * The global time target of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#global_time_target Dashboard#global_time_target}
     *
     * @stability stable
     */
    readonly globalTimeTarget?: string;
    /**
     * Whether to show the error budget or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_error_budget Dashboard#show_error_budget}
     *
     * @stability stable
     */
    readonly showErrorBudget?: boolean | cdktf.IResolvable;
    /**
     * The ID of the service level objective used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#slo_id Dashboard#slo_id}
     *
     * @stability stable
     */
    readonly sloId: string;
    /**
     * A list of time windows to display in the widget.
     *
     * Valid values are `7d`, `30d`, `90d`, `week_to_date`, `previous_week`, `month_to_date`, `previous_month`, `global_time`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#time_windows Dashboard#time_windows}
     *
     * @stability stable
     */
    readonly timeWindows: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * The view mode for the widget. Valid values are `overall`, `component`, `both`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view_mode Dashboard#view_mode}
     *
     * @stability stable
     */
    readonly viewMode: string;
    /**
     * The type of view to use when displaying the widget. Only `detail` is supported.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view_type Dashboard#view_type}
     *
     * @stability stable
     */
    readonly viewType: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetServicemapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetServicemapDefinition {
    /**
     * Your environment and primary tag (or `*` if enabled for your account).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filters Dashboard#filters}
     *
     * @stability stable
     */
    readonly filters: string[];
    /**
     * The ID of the service to map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetServicemapDefinitionCustomLink[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionEvent {
    /**
     * The event query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q: string;
    /**
     * The execution method for multi-value filters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionMarker {
    /**
     * How the marker lines are displayed, options are one of {`error`, `warning`, `info`, `ok`} combined with one of {`dashed`, `solid`, `bold`}.
     *
     * Example: `error dashed`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_type Dashboard#display_type}
     *
     * @stability stable
     */
    readonly displayType?: string;
    /**
     * A label for the line or range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * A mathematical expression describing the marker, for example: `y > 1`, `-5 < y < 0`, `y = 19`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetTimeseriesDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetTimeseriesDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetTimeseriesDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetTimeseriesDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetTimeseriesDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetTimeseriesDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetTimeseriesDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetTimeseriesDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetTimeseriesDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetTimeseriesDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestMetadata {
    /**
     * The expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias_name Dashboard#alias_name}
     *
     * @stability stable
     */
    readonly aliasName?: string;
    /**
     * The expression name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#expression Dashboard#expression}
     *
     * @stability stable
     */
    readonly expression: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetTimeseriesDefinitionRequestNetworkQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestNetworkQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetTimeseriesDefinitionRequestNetworkQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetTimeseriesDefinitionRequestNetworkQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetTimeseriesDefinitionRequestNetworkQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetTimeseriesDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetTimeseriesDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetTimeseriesDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetTimeseriesDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetTimeseriesDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetTimeseriesDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetTimeseriesDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetTimeseriesDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetTimeseriesDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetTimeseriesDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetTimeseriesDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetTimeseriesDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetTimeseriesDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetTimeseriesDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequestStyle {
    /**
     * The type of lines displayed. Valid values are `dashed`, `dotted`, `solid`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#line_type Dashboard#line_type}
     *
     * @stability stable
     */
    readonly lineType?: string;
    /**
     * The width of line displayed. Valid values are `normal`, `thick`, `thin`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#line_width Dashboard#line_width}
     *
     * @stability stable
     */
    readonly lineWidth?: string;
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRequest {
    /**
     * How to display the marker lines. Valid values are `area`, `bars`, `line`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_type Dashboard#display_type}
     *
     * @stability stable
     */
    readonly displayType?: string;
    /**
     * A Boolean indicating whether the request uses the right or left Y-Axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#on_right_yaxis Dashboard#on_right_yaxis}
     *
     * @stability stable
     */
    readonly onRightYaxis?: boolean | cdktf.IResolvable;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetTimeseriesDefinitionRequestApmQuery[];
    /**
     * audit_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#audit_query Dashboard#audit_query}
     *
     * @stability stable
     */
    readonly auditQuery?: DashboardWidgetTimeseriesDefinitionRequestAuditQuery[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetTimeseriesDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetTimeseriesDefinitionRequestLogQuery[];
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metadata Dashboard#metadata}
     *
     * @stability stable
     */
    readonly metadata?: DashboardWidgetTimeseriesDefinitionRequestMetadata[];
    /**
     * network_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#network_query Dashboard#network_query}
     *
     * @stability stable
     */
    readonly networkQuery?: DashboardWidgetTimeseriesDefinitionRequestNetworkQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetTimeseriesDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetTimeseriesDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetTimeseriesDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetTimeseriesDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetTimeseriesDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionRightYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetTimeseriesDefinition {
    /**
     * A list of columns to display in the legend. Valid values are `value`, `avg`, `sum`, `min`, `max`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_columns Dashboard#legend_columns}
     *
     * @stability stable
     */
    readonly legendColumns?: string[];
    /**
     * The layout of the legend displayed in the widget. Valid values are `auto`, `horizontal`, `vertical`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_layout Dashboard#legend_layout}
     *
     * @stability stable
     */
    readonly legendLayout?: string;
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetTimeseriesDefinitionCustomLink[];
    /**
     * event block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event Dashboard#event}
     *
     * @stability stable
     */
    readonly event?: DashboardWidgetTimeseriesDefinitionEvent[];
    /**
     * marker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#marker Dashboard#marker}
     *
     * @stability stable
     */
    readonly marker?: DashboardWidgetTimeseriesDefinitionMarker[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetTimeseriesDefinitionRequest[];
    /**
     * right_yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#right_yaxis Dashboard#right_yaxis}
     *
     * @stability stable
     */
    readonly rightYaxis?: DashboardWidgetTimeseriesDefinitionRightYaxis[];
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetTimeseriesDefinitionYaxis[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetToplistDefinitionRequestApmQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetToplistDefinitionRequestApmQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetToplistDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetToplistDefinitionRequestApmQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetToplistDefinitionRequestAuditQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetToplistDefinitionRequestAuditQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetToplistDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetToplistDefinitionRequestAuditQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetToplistDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetToplistDefinitionRequestFormulaLimit[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetToplistDefinitionRequestLogQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetToplistDefinitionRequestLogQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetToplistDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetToplistDefinitionRequestLogQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetToplistDefinitionRequestQueryEventQueryGroupBySort[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetToplistDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetToplistDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetToplistDefinitionRequestQueryEventQuerySearch[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestQuery {
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetToplistDefinitionRequestQueryEventQuery[];
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetToplistDefinitionRequestQueryMetricQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetToplistDefinitionRequestQueryProcessQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetToplistDefinitionRequestRumQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetToplistDefinitionRequestRumQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetToplistDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetToplistDefinitionRequestRumQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetToplistDefinitionRequestSecurityQueryGroupBySortQuery[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetToplistDefinitionRequestSecurityQueryComputeQuery[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetToplistDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetToplistDefinitionRequestSecurityQueryMultiCompute[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetToplistDefinitionRequestApmQuery[];
    /**
     * audit_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#audit_query Dashboard#audit_query}
     *
     * @stability stable
     */
    readonly auditQuery?: DashboardWidgetToplistDefinitionRequestAuditQuery[];
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetToplistDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetToplistDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetToplistDefinitionRequestLogQuery[];
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetToplistDefinitionRequestProcessQuery[];
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetToplistDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetToplistDefinitionRequestRumQuery[];
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetToplistDefinitionRequestSecurityQuery[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetToplistDefinitionRequestStyle[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetToplistDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetToplistDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetToplistDefinitionRequest[];
}
/**
 * @stability stable
 */
export interface DashboardWidgetTraceServiceDefinition {
    /**
     * The number of columns to display. Valid values are `one_column`, `two_column`, `three_column`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_format Dashboard#display_format}
     *
     * @stability stable
     */
    readonly displayFormat?: string;
    /**
     * APM environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * Whether to show the latency breakdown or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_breakdown Dashboard#show_breakdown}
     *
     * @stability stable
     */
    readonly showBreakdown?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the latency distribution or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_distribution Dashboard#show_distribution}
     *
     * @stability stable
     */
    readonly showDistribution?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the error metrics or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_errors Dashboard#show_errors}
     *
     * @stability stable
     */
    readonly showErrors?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the hits metrics or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_hits Dashboard#show_hits}
     *
     * @stability stable
     */
    readonly showHits?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the latency metrics or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_latency Dashboard#show_latency}
     *
     * @stability stable
     */
    readonly showLatency?: boolean | cdktf.IResolvable;
    /**
     * Whether to show the resource list or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_resource_list Dashboard#show_resource_list}
     *
     * @stability stable
     */
    readonly showResourceList?: boolean | cdktf.IResolvable;
    /**
     * The size of the widget. Valid values are `small`, `medium`, `large`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#size_format Dashboard#size_format}
     *
     * @stability stable
     */
    readonly sizeFormat?: string;
    /**
     * APM span name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#span_name Dashboard#span_name}
     *
     * @stability stable
     */
    readonly spanName: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
/**
 * @stability stable
 */
export interface DashboardWidgetWidgetLayout {
    /**
     * The height of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#height Dashboard#height}
     *
     * @stability stable
     */
    readonly height: number;
    /**
     * Whether the widget should be the first one on the second column in high density or not.
     *
     * Only for the new dashboard layout and only one widget in the dashboard should have this property set to `true`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_column_break Dashboard#is_column_break}
     *
     * @stability stable
     */
    readonly isColumnBreak?: boolean | cdktf.IResolvable;
    /**
     * The width of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#width Dashboard#width}
     *
     * @stability stable
     */
    readonly width: number;
    /**
     * The position of the widget on the x (horizontal) axis. Should be greater than or equal to 0.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#x Dashboard#x}
     *
     * @stability stable
     */
    readonly x: number;
    /**
     * The position of the widget on the y (vertical) axis. Should be greater than or equal to 0.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#y Dashboard#y}
     *
     * @stability stable
     */
    readonly y: number;
}
/**
 * @stability stable
 */
export interface DashboardWidget {
    /**
     * alert_graph_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_graph_definition Dashboard#alert_graph_definition}
     *
     * @stability stable
     */
    readonly alertGraphDefinition?: DashboardWidgetAlertGraphDefinition[];
    /**
     * alert_value_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_value_definition Dashboard#alert_value_definition}
     *
     * @stability stable
     */
    readonly alertValueDefinition?: DashboardWidgetAlertValueDefinition[];
    /**
     * change_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#change_definition Dashboard#change_definition}
     *
     * @stability stable
     */
    readonly changeDefinition?: DashboardWidgetChangeDefinition[];
    /**
     * check_status_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#check_status_definition Dashboard#check_status_definition}
     *
     * @stability stable
     */
    readonly checkStatusDefinition?: DashboardWidgetCheckStatusDefinition[];
    /**
     * distribution_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#distribution_definition Dashboard#distribution_definition}
     *
     * @stability stable
     */
    readonly distributionDefinition?: DashboardWidgetDistributionDefinition[];
    /**
     * event_stream_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_stream_definition Dashboard#event_stream_definition}
     *
     * @stability stable
     */
    readonly eventStreamDefinition?: DashboardWidgetEventStreamDefinition[];
    /**
     * event_timeline_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_timeline_definition Dashboard#event_timeline_definition}
     *
     * @stability stable
     */
    readonly eventTimelineDefinition?: DashboardWidgetEventTimelineDefinition[];
    /**
     * free_text_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#free_text_definition Dashboard#free_text_definition}
     *
     * @stability stable
     */
    readonly freeTextDefinition?: DashboardWidgetFreeTextDefinition[];
    /**
     * geomap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#geomap_definition Dashboard#geomap_definition}
     *
     * @stability stable
     */
    readonly geomapDefinition?: DashboardWidgetGeomapDefinition[];
    /**
     * group_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_definition Dashboard#group_definition}
     *
     * @stability stable
     */
    readonly groupDefinition?: DashboardWidgetGroupDefinition[];
    /**
     * heatmap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#heatmap_definition Dashboard#heatmap_definition}
     *
     * @stability stable
     */
    readonly heatmapDefinition?: DashboardWidgetHeatmapDefinition[];
    /**
     * hostmap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hostmap_definition Dashboard#hostmap_definition}
     *
     * @stability stable
     */
    readonly hostmapDefinition?: DashboardWidgetHostmapDefinition[];
    /**
     * iframe_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#iframe_definition Dashboard#iframe_definition}
     *
     * @stability stable
     */
    readonly iframeDefinition?: DashboardWidgetIframeDefinition[];
    /**
     * image_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_definition Dashboard#image_definition}
     *
     * @stability stable
     */
    readonly imageDefinition?: DashboardWidgetImageDefinition[];
    /**
     * log_stream_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_stream_definition Dashboard#log_stream_definition}
     *
     * @stability stable
     */
    readonly logStreamDefinition?: DashboardWidgetLogStreamDefinition[];
    /**
     * manage_status_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#manage_status_definition Dashboard#manage_status_definition}
     *
     * @stability stable
     */
    readonly manageStatusDefinition?: DashboardWidgetManageStatusDefinition[];
    /**
     * note_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#note_definition Dashboard#note_definition}
     *
     * @stability stable
     */
    readonly noteDefinition?: DashboardWidgetNoteDefinition[];
    /**
     * query_table_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query_table_definition Dashboard#query_table_definition}
     *
     * @stability stable
     */
    readonly queryTableDefinition?: DashboardWidgetQueryTableDefinition[];
    /**
     * query_value_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query_value_definition Dashboard#query_value_definition}
     *
     * @stability stable
     */
    readonly queryValueDefinition?: DashboardWidgetQueryValueDefinition[];
    /**
     * scatterplot_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scatterplot_definition Dashboard#scatterplot_definition}
     *
     * @stability stable
     */
    readonly scatterplotDefinition?: DashboardWidgetScatterplotDefinition[];
    /**
     * service_level_objective_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service_level_objective_definition Dashboard#service_level_objective_definition}
     *
     * @stability stable
     */
    readonly serviceLevelObjectiveDefinition?: DashboardWidgetServiceLevelObjectiveDefinition[];
    /**
     * servicemap_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#servicemap_definition Dashboard#servicemap_definition}
     *
     * @stability stable
     */
    readonly servicemapDefinition?: DashboardWidgetServicemapDefinition[];
    /**
     * timeseries_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeseries_definition Dashboard#timeseries_definition}
     *
     * @stability stable
     */
    readonly timeseriesDefinition?: DashboardWidgetTimeseriesDefinition[];
    /**
     * toplist_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#toplist_definition Dashboard#toplist_definition}
     *
     * @stability stable
     */
    readonly toplistDefinition?: DashboardWidgetToplistDefinition[];
    /**
     * trace_service_definition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#trace_service_definition Dashboard#trace_service_definition}
     *
     * @stability stable
     */
    readonly traceServiceDefinition?: DashboardWidgetTraceServiceDefinition[];
    /**
     * widget_layout block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#widget_layout Dashboard#widget_layout}
     *
     * @stability stable
     */
    readonly widgetLayout?: DashboardWidgetWidgetLayout[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html datadog_dashboard}.
 *
 * @stability stable
 */
export declare class Dashboard extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html datadog_dashboard} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DashboardConfig);
    private _dashboardLists?;
    /**
     * @stability stable
     */
    get dashboardLists(): number[];
    /**
     * @stability stable
     */
    set dashboardLists(value: number[]);
    /**
     * @stability stable
     */
    resetDashboardLists(): void;
    /**
     * @stability stable
     */
    get dashboardListsInput(): number[] | undefined;
    /**
     * @stability stable
     */
    get dashboardListsRemoved(): any;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _isReadOnly?;
    /**
     * @stability stable
     */
    get isReadOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isReadOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsReadOnly(): void;
    /**
     * @stability stable
     */
    get isReadOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _layoutType;
    /**
     * @stability stable
     */
    get layoutType(): string;
    /**
     * @stability stable
     */
    set layoutType(value: string);
    /**
     * @stability stable
     */
    get layoutTypeInput(): string;
    private _notifyList?;
    /**
     * @stability stable
     */
    get notifyList(): string[];
    /**
     * @stability stable
     */
    set notifyList(value: string[]);
    /**
     * @stability stable
     */
    resetNotifyList(): void;
    /**
     * @stability stable
     */
    get notifyListInput(): string[] | undefined;
    private _reflowType?;
    /**
     * @stability stable
     */
    get reflowType(): string;
    /**
     * @stability stable
     */
    set reflowType(value: string);
    /**
     * @stability stable
     */
    resetReflowType(): void;
    /**
     * @stability stable
     */
    get reflowTypeInput(): string | undefined;
    private _restrictedRoles?;
    /**
     * @stability stable
     */
    get restrictedRoles(): string[];
    /**
     * @stability stable
     */
    set restrictedRoles(value: string[]);
    /**
     * @stability stable
     */
    resetRestrictedRoles(): void;
    /**
     * @stability stable
     */
    get restrictedRolesInput(): string[] | undefined;
    private _title;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    get titleInput(): string;
    private _url?;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    set url(value: string);
    /**
     * @stability stable
     */
    resetUrl(): void;
    /**
     * @stability stable
     */
    get urlInput(): string | undefined;
    private _templateVariable?;
    /**
     * @stability stable
     */
    get templateVariable(): DashboardTemplateVariable[];
    /**
     * @stability stable
     */
    set templateVariable(value: DashboardTemplateVariable[]);
    /**
     * @stability stable
     */
    resetTemplateVariable(): void;
    /**
     * @stability stable
     */
    get templateVariableInput(): DashboardTemplateVariable[] | undefined;
    private _templateVariablePreset?;
    /**
     * @stability stable
     */
    get templateVariablePreset(): DashboardTemplateVariablePreset[];
    /**
     * @stability stable
     */
    set templateVariablePreset(value: DashboardTemplateVariablePreset[]);
    /**
     * @stability stable
     */
    resetTemplateVariablePreset(): void;
    /**
     * @stability stable
     */
    get templateVariablePresetInput(): DashboardTemplateVariablePreset[] | undefined;
    private _widget;
    /**
     * @stability stable
     */
    get widget(): DashboardWidget[];
    /**
     * @stability stable
     */
    set widget(value: DashboardWidget[]);
    /**
     * @stability stable
     */
    get widgetInput(): DashboardWidget[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
